Chunkerstrategywithoverlapdetection
Initial-cap chunker strategy class.
Usage
Chunkerstrategywithoverlapdetection()This class name starts with an uppercase letter and the rest is entirely lowercase, with no other separators.
Parameters
maxchunksize: int = 1000-
Maximum size of each chunk in characters.
overlapsize: int = 200-
Number of overlapping characters between chunks.